@@ -18,12 +18,15 @@ os <- function() {
   os <- stats::setNames(as.list(os$val), os$var)
   code <- switch(
     id <- strsplit(os$ID, "-")[[1]][1],
-    "debian" = , "ubuntu" = os$VERSION_CODENAME,
+    "debian" = , "ubuntu" = , "pop" = os$VERSION_CODENAME,
     "centos" = , "rocky"  = , "almalinux" = , "ol" = , "rhel" =
       paste0(if ((ver <- safe_version(os$VERSION_ID)$major) < 9)
         "centos" else "rhel", ver),
-    "amzn"   = if (os$VERSION_ID == "2") "centos7" else
-      stop("OS not supported", call.=FALSE),
+    "amzn"   = switch(
+      os$VERSION_ID,
+      "2"    = "centos7",
+      "2023" = "rhel9",
+      stop("OS not supported", call.=FALSE)),
     "sles"   = , "opensuse" =
       paste0("opensuse", sub("\\.", "", os$VERSION_ID)),
     stop("OS not supported", call.=FALSE)
